@@ -1,7 +1,7 @@
 import os
 import sys
 from datetime import timedelta
-from typing import Callable
+from typing import Callable, Optional
 
 from click import (
     Choice,
@@ -22,11 +22,16 @@ from firebolt.service.types import (
     WarmupMethod,
 )
 
-from firebolt_cli.common_options import common_options, json_option
+from firebolt_cli.common_options import (
+    common_options,
+    default_from_config_file,
+    json_option,
+)
 from firebolt_cli.utils import (
     construct_resource_manager,
     construct_shortcuts,
     exit_on_firebolt_exception,
+    get_default_database_engine,
     prepare_execution_result_line,
     prepare_execution_result_table,
     string_to_int_or_none,
@@ -69,10 +74,26 @@ AVAILABLE_NEW_ENGINES = [
 )
 def engine() -> None:
     """
-    Manage the engines
+    Manage engines.
     """
 
 
+def get_engine_from_name_or_default(
+    rm: ResourceManager, engine_name: Optional[str], database_name: Optional[str]
+) -> Engine:
+    """
+    Returns engine either from its name, or a default engine deducted
+    from database_name. At least one engine_name or database_name should
+    be provided, raises an Error otherwise.
+    """
+    if engine_name is not None:
+        return rm.engines.get_by_name(name=engine_name)
+    elif database_name is not None:
+        return get_default_database_engine(rm, database_name)
+    else:
+        raise FireboltError("Either engine name or database name has to be specified")
+
+
 def start_stop_generic(
     engine: Engine,
     action: str,
@@ -124,36 +145,42 @@ def start_stop_generic(
 
 @command()
 @common_options
+@option(
+    "--database-name",
+    envvar="FIREBOLT_DATABASE_NAME",
+    help="Alternatively to engine name, database name could be specified, "
+    "its default engine will be used",
+    hidden=True,
+    callback=default_from_config_file(required=False),
+)
 @option(
     "--wait/--no-wait",
-    help="Wait until the engine is started",
+    help="Wait until the engine is started.",
     is_flag=True,
     default=False,
 )
-@argument(
-    "engine_name",
-    type=str,
-)
+@argument("engine_name", type=str, required=False)
 @exit_on_firebolt_exception
 def start(**raw_config_options: str) -> None:
     """
-    Start an existing engine
+    Start an existing ENGINE_NAME. If ENGINE_NAME is not set,
+    uses default engine instead.
     """
 
     rm = construct_resource_manager(**raw_config_options)
-    engine = rm.engines.get_by_name(name=raw_config_options["engine_name"])
+    engine = get_engine_from_name_or_default(
+        rm, raw_config_options["engine_name"], raw_config_options["database_name"]
+    )
 
     if (
         engine.current_status_summary
         == EngineStatusSummary.ENGINE_STATUS_SUMMARY_FAILED
     ):
-        echo(
+        raise FireboltError(
             f"Engine {engine.name} is in a failed state.\n"
             f"You need to restart an engine first:\n"
-            f"$ firebolt restart --engine-name {engine.name}",
-            err=True,
+            f"$ firebolt restart {engine.name}"
         )
-        sys.exit(1)
 
     start_stop_generic(
         engine=engine,
@@ -166,10 +193,10 @@ def start(**raw_config_options: str) -> None:
         accepted_final_nowait_states={
             EngineStatusSummary.ENGINE_STATUS_SUMMARY_STARTING
         },
-        wrong_initial_state_error="Engine {name} is not in a stopped state,"
-        " the current engine state is {state}",
-        success_message="Engine {name} is successfully started",
-        success_message_nowait="Start request for engine {name} is successfully sent",
+        wrong_initial_state_error="Engine {name} is not in a stopped state."
+        "The current engine state is {state}.",
+        success_message="Engine {name} is successfully started.",
+        success_message_nowait="Start request for engine {name} is successfully sent.",
         failure_message="Engine {name} failed to start. Engine status: {status}.",
         **raw_config_options,
     )
@@ -177,24 +204,32 @@ def start(**raw_config_options: str) -> None:
 
 @command()
 @common_options
+@option(
+    "--database-name",
+    envvar="FIREBOLT_DATABASE_NAME",
+    help="Alternatively to engine name, database name could be specified, "
+    "its default engine will be used",
+    hidden=True,
+    callback=default_from_config_file(required=False),
+)
 @option(
     "--wait/--no-wait",
-    help="Wait until the engine is stopped",
+    help="Wait until the engine is stopped.",
     is_flag=True,
     default=False,
 )
-@argument(
-    "engine_name",
-    type=str,
-)
+@argument("engine_name", type=str, required=False)
 @exit_on_firebolt_exception
 def stop(**raw_config_options: str) -> None:
     """
-    Stop an existing engine
+    Stop an existing ENGINE_NAME. If ENGINE_NAME is not set,
+    uses default engine instead.
     """
 
     rm = construct_resource_manager(**raw_config_options)
-    engine = rm.engines.get_by_name(name=raw_config_options["engine_name"])
+    engine = get_engine_from_name_or_default(
+        rm, raw_config_options["engine_name"], raw_config_options["database_name"]
+    )
 
     start_stop_generic(
         engine=engine,
@@ -208,10 +243,10 @@ def stop(**raw_config_options: str) -> None:
             EngineStatusSummary.ENGINE_STATUS_SUMMARY_STOPPING,
             EngineStatusSummary.ENGINE_STATUS_SUMMARY_STOPPED,
         },
-        wrong_initial_state_error="Engine {name} is not in a running or starting state,"
-        " the current engine state is {state}",
-        success_message="Engine {name} is successfully stopped",
-        success_message_nowait="Stop request for engine {name} is successfully sent",
+        wrong_initial_state_error="Engine {name} is not in a running or starting state."
+        " The current engine state is {state}.",
+        success_message="Engine {name} is successfully stopped.",
+        success_message_nowait="Stop request for engine {name} is successfully sent.",
         failure_message="Engine {name} failed to stop. Engine status: {status}.",
         **raw_config_options,
     )
@@ -221,12 +256,12 @@ def engine_properties_options(create_mode: bool = True) -> Callable:
     """
     decorator for engine create/update common options
 
-    :param create_mode: True for create, will make some of the options required
+    :param create_mode: True for create, will make some options required
     """
     _ENGINE_OPTIONS = [
         option(
             "--name",
-            help="Name of the engine",
+            help="Name of the engine.",
             type=str,
             required=True,
         ),
@@ -241,38 +276,43 @@ def engine_properties_options(create_mode: bool = True) -> Callable:
         ),
         option(
             "--description",
-            help="Engine description",
+            help="Engine description (max: 64 characters).",
             type=str,
             default="" if create_mode else None,
             required=False,
         ),
         option(
             "--type",
-            help="Engine type: rw for general purpose and ro for data analytics",
+            help='Engine type: "rw" for general purpose '
+            'and "ro" for data analytics.',
             type=Choice(list(ENGINE_TYPES.keys()), case_sensitive=False),
             default="ro" if create_mode else None,
             required=False,
         ),
         option(
             "--scale",
-            help="Engine scale",
+            help="The number of engine nodes. Value entered must be between 1 and 128.",
             type=IntRange(1, 128, clamp=False),
             default=1 if create_mode else None,
             required=False,
             show_default=True,
+            metavar="INTEGER",
         ),
         option(
             "--auto-stop",
-            help="Stop engine automatically after specified time in minutes",
+            help="Stop engine automatically after specified time in minutes."
+            "Value entered must be between 1 and 43200"
+            "(max value is equal to 30 days).",
             type=IntRange(1, 30 * 24 * 60, clamp=False),
             default=20 if create_mode else None,
             required=False,
             show_default=True,
+            metavar="INTEGER",
         ),
         option(
             "--warmup",
             help="Engine warmup method. "
-            "Minimal(min), Preload indexes(ind), Preload all data(all) ",
+            "Minimal(min), Preload indexes(ind), Preload all data(all)",
             type=Choice(list(WARMUP_METHODS.keys())),
             default="ind" if create_mode else None,
             required=False,
@@ -367,24 +407,32 @@ WARMUP_METHODS = {
 
 @command()
 @common_options
+@option(
+    "--database-name",
+    envvar="FIREBOLT_DATABASE_NAME",
+    help="Alternatively to engine name, database name could be specified, "
+    "its default engine will be used",
+    hidden=True,
+    callback=default_from_config_file(required=False),
+)
 @option(
     "--wait/--no-wait",
-    help="Wait until the engine is restarted",
+    help="Wait until the engine is restarted.",
     is_flag=True,
     default=False,
 )
-@argument(
-    "engine_name",
-    type=str,
-)
+@argument("engine_name", type=str, required=False)
 @exit_on_firebolt_exception
 def restart(**raw_config_options: str) -> None:
     """
-    Restart an existing engine
+    Restart an existing ENGINE_NAME. If ENGINE_NAME is not set,
+    uses default engine instead.
     """
 
     rm = construct_resource_manager(**raw_config_options)
-    engine = rm.engines.get_by_name(name=raw_config_options["engine_name"])
+    engine = get_engine_from_name_or_default(
+        rm, raw_config_options["engine_name"], raw_config_options["database_name"]
+    )
 
     start_stop_generic(
         engine=engine,
@@ -398,10 +446,11 @@ def restart(**raw_config_options: str) -> None:
             EngineStatusSummary.ENGINE_STATUS_SUMMARY_STOPPING,
             EngineStatusSummary.ENGINE_STATUS_SUMMARY_STARTING,
         },
-        wrong_initial_state_error="Engine {name} is not in a running or failed state,"
-        " the current engine state is {state}",
-        success_message="Engine {name} is successfully restarted",
-        success_message_nowait="Restart request for engine {name} is successfully sent",
+        wrong_initial_state_error="Engine {name} is not in a running or failed state."
+        " The current engine state is {state}.",
+        success_message="Engine {name} is successfully restarted.",
+        success_message_nowait="Restart request for engine {name} "
+        "is successfully sent.",
         failure_message="Engine {name} failed to restart. Engine status: {status}.",
         **raw_config_options,
     )
@@ -410,10 +459,10 @@ def restart(**raw_config_options: str) -> None:
 @command()
 @common_options
 @engine_properties_options(create_mode=True)
-@option("--name", help="Name of the engine", type=str, required=True)
+@option("--name", help="Name of the engine.", type=str, required=True)
 @option(
     "--database-name",
-    help="Name of the database the engine should be attached to",
+    help="Name of the database the engine should be attached to.",
     type=str,
     required=True,
 )
@@ -421,7 +470,7 @@ def restart(**raw_config_options: str) -> None:
 @exit_on_firebolt_exception
 def create(**raw_config_options: str) -> None:
     """
-    Creates engine with the requested parameters
+    Creates engine with the requested parameters.
     """
     rm = construct_resource_manager(**raw_config_options)
 
@@ -448,7 +497,7 @@ def create(**raw_config_options: str) -> None:
     if not raw_config_options["json"]:
         echo(
             f"Engine {engine.name} is successfully created "
-            f"and attached to the {database.name}"
+            f"and attached to the {database.name}."
         )
 
     echo_engine_information(rm, engine, bool(raw_config_options["json"]))
@@ -459,7 +508,7 @@ def create(**raw_config_options: str) -> None:
 @engine_properties_options(create_mode=False)
 @option(
     "--new-engine-name",
-    help="Set this parameter for renaming the engine",
+    help="Set this parameter for renaming the engine.",
     default=None,
     required=False,
 )
@@ -467,7 +516,7 @@ def create(**raw_config_options: str) -> None:
 @exit_on_firebolt_exception
 def update(**raw_config_options: str) -> None:
     """
-    Update engine parameters, engine should be stopped before update
+    Update engine parameters. Engine should be stopped before updating.
     """
     something_to_update = any(
         raw_config_options[param] is not None
@@ -482,7 +531,7 @@ def update(**raw_config_options: str) -> None:
     )
 
     if not something_to_update:
-        echo("Nothing to update, at least one parameter should be provided", err=True)
+        echo("Nothing to update. At least one parameter should be provided.", err=True)
         sys.exit(os.EX_USAGE)
 
     rm = construct_resource_manager(**raw_config_options)
@@ -500,36 +549,46 @@ def update(**raw_config_options: str) -> None:
     )
 
     if not raw_config_options["json"]:
-        echo(f"Engine {engine.name} is successfully updated")
+        echo(f"Engine {engine.name} is successfully updated.")
 
     echo_engine_information(rm, engine, bool(raw_config_options["json"]))
 
 
 @command()
 @common_options
-@argument(
-    "engine_name",
-    type=str,
+@option(
+    "--database-name",
+    envvar="FIREBOLT_DATABASE_NAME",
+    help="Alternatively to engine name, database name could be specified, "
+    "its default engine will be used",
+    hidden=True,
+    callback=default_from_config_file(required=False),
 )
+@argument("engine_name", type=str, required=False)
 @exit_on_firebolt_exception
 def status(**raw_config_options: str) -> None:
     """
-    Check the engine status
+    Check the ENGINE_NAME status. If ENGINE_NAME is not set,
+    uses default engine instead.
     """
 
     rm = construct_resource_manager(**raw_config_options)
-    engine = rm.engines.get_by_name(name=raw_config_options["engine_name"])
+    engine = get_engine_from_name_or_default(
+        rm, raw_config_options["engine_name"], raw_config_options["database_name"]
+    )
+
     current_status_name = (
         engine.current_status_summary.name if engine.current_status_summary else ""
     )
     echo(f"Engine {engine.name} current status is: {current_status_name}")
 
 
-@command(name="list (ls)")
+@command(name="list", short_help="List existing engines (alias: ls)")
 @common_options
 @option(
     "--name-contains",
-    help="Output engines will be filtered by name-contains",
+    help="A string used to filter the list of returned engines. "
+    "Partial matches will be returned.",
     default=None,
     type=str,
 )
