@@ -4,7 +4,9 @@ from firebolt_cli import __version__
 from firebolt_cli.configure import configure
 from firebolt_cli.database import database
 from firebolt_cli.engine import engine
+from firebolt_cli.ingest import ingest
 from firebolt_cli.query import query
+from firebolt_cli.table import table
 from firebolt_cli.utils import construct_shortcuts
 
 
@@ -15,6 +17,8 @@ from firebolt_cli.utils import construct_shortcuts
             "configure": "configure (config)",
             "db": "database (db)",
             "database": "database (db)",
+            "tb": "table (tb)",
+            "table": "table (tb)",
         }
     )
 )
@@ -25,7 +29,9 @@ def main() -> None:
     """
 
 
+main.add_command(ingest)
 main.add_command(configure)
 main.add_command(engine)
 main.add_command(query)
 main.add_command(database)
+main.add_command(table)
